Emperor’s Documentation — Emperor 0.9.51-dev documentation

# Emperor’s Documentation

Emperor is an interactive next generation tool for the analysis, visualization and understanding of high throughput microbial ecology datasets.

The Index lists the contents of this documentation.

- Emperor’s public API
  - Emperor 3D PCoA viewer (`emperor`)
    - Classes
      - emperor.Emperor
    - Functions
      - emperor.nbinstall
      - emperor.scatterplot

# Format Description:

- File Formats
  - Mapping File
  - Coordinates File

# Citing Emperor

Remember to cite Emperor If you use it in any published research, please include the following citation:

Note

EMPeror: a tool for visualizing high-throughput microbial community data. Vazquez-Baeza Y, Pirrung M, Gonzalez A, Knight R. Gigascience. 2013 Nov 26;2(1):16.

You can find the Emperor paper here, and the data presented in this paper can be found here.